@@ -1,5 +1,5 @@
 """
-The "get" command group
+The "block" command group
 """
 
 from typing import Optional
@@ -7,11 +7,8 @@ from typing import Optional
 from click import argument, command, group
 
 from ..options import rpc_endpoint_option
-
-# Disable pylint warning about imports outside top-level.  We do this
-# intentionally to try and keep startup times of the CLI low.
-
-# pylint: disable=import-outside-toplevel
+from ..user import get_block
+from ..utils import to_json, validate_block_identifier, web3_from_endpoint_arg
 
 
 @group(name="block")
@@ -26,12 +23,10 @@ def block_group() -> None:
 @argument("identifier", default="latest")
 def get(rpc_endpoint: Optional[str], identifier: str) -> None:
     """
-    Print information for block, where <identifier> is a block number
-    or hash.  If no argument is given, "latest" is used.
-    """
+    Print information for block.
 
-    from ..user import get_block
-    from ..utils import to_json, validate_block_identifier, web3_from_endpoint_arg
+    <identifier> is a block number or hash. If no argument is given, "latest" is used.
+    """
 
     block_id = validate_block_identifier(identifier)
     w3 = web3_from_endpoint_arg(None, rpc_endpoint)
@@ -49,8 +44,6 @@ def height(rpc_endpoint: Optional[str]) -> None:
     Print the current block height for the chain.
     """
 
-    from ..utils import web3_from_endpoint_arg
-
     w3 = web3_from_endpoint_arg(None, rpc_endpoint)
     print(w3.eth.block_number)
 
