@@ -5,12 +5,16 @@ The `gov` command group.
 from typing import Optional
 
 from click import argument, command, group
+from web3 import Web3
 
-from ..options import (
-    from_option,
-    keyfile_option,
-    rpc_endpoint_option,
-    tx_aux_options,
+from ..options import from_option, keyfile_option, rpc_endpoint_option, tx_aux_options
+from ..utils import (
+    autonity_from_endpoint_arg,
+    create_contract_tx_from_args,
+    from_address_from_argument,
+    parse_newton_value_representation,
+    parse_wei_representation,
+    to_json,
 )
 
 
@@ -26,8 +30,11 @@ def governance_group() -> None:
 @keyfile_option()
 @from_option
 @tx_aux_options
-@argument("gas_value_str", metavar="gas", nargs=1)
-def set_max_bond_applied_gas(
+@argument("schedule-vault", metavar="ADDRESS")
+@argument("amount", type=int)
+@argument("start-time", type=int)
+@argument("total-duration", type=int)
+def create_schedule(
     rpc_endpoint: Optional[str],
     keyfile: Optional[str],
     from_str: Optional[str],
@@ -38,26 +45,23 @@ def set_max_bond_applied_gas(
     fee_factor: Optional[float],
     nonce: Optional[int],
     chain_id: Optional[int],
-    gas_value_str: str,
+    schedule_vault: str,
+    amount: int,
+    start_time: int,
+    duration: int,
 ) -> None:
     """
-    Set the maximum bond applied gas. Restricted to the operator account.
-    See `setMaxBondAppliedGas` on the Autonity contract.
-    """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
+    Create a new schedule.
 
-    gas_value = parse_wei_representation(gas_value_str)
+    Restricted to the Operator account. See `createSchedule` on Autonity contract.
+    """
+
+    vault_address = Web3.to_checksum_address(schedule_vault)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
     tx = create_contract_tx_from_args(
-        function=aut.set_max_bond_applied_gas(gas_value),
+        function=aut.create_schedule(vault_address, amount, start_time, duration),
         from_addr=from_addr,
         gas=gas,
         gas_price=gas_price,
@@ -70,215 +74,7 @@ def set_max_bond_applied_gas(
     print(to_json(tx))
 
 
-governance_group.add_command(set_max_bond_applied_gas)
-
-
-@command()
-@rpc_endpoint_option
-@keyfile_option()
-@from_option
-@tx_aux_options
-@argument("gas_value_str", metavar="gas", nargs=1)
-def set_max_unbond_applied_gas(
-    rpc_endpoint: Optional[str],
-    keyfile: Optional[str],
-    from_str: Optional[str],
-    gas: Optional[str],
-    gas_price: Optional[str],
-    max_priority_fee_per_gas: Optional[str],
-    max_fee_per_gas: Optional[str],
-    fee_factor: Optional[float],
-    nonce: Optional[int],
-    chain_id: Optional[int],
-    gas_value_str: str,
-) -> None:
-    """
-    Set the maximum unbond applied gas. Restricted to the operator account.
-    See `setMaxBondAppliedGas` on the Autonity contract.
-    """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
-
-    gas_value = parse_wei_representation(gas_value_str)
-    from_addr = from_address_from_argument(from_str, keyfile)
-    aut = autonity_from_endpoint_arg(rpc_endpoint)
-
-    tx = create_contract_tx_from_args(
-        function=aut.set_max_unbond_applied_gas(gas_value),
-        from_addr=from_addr,
-        gas=gas,
-        gas_price=gas_price,
-        max_fee_per_gas=max_fee_per_gas,
-        max_priority_fee_per_gas=max_priority_fee_per_gas,
-        fee_factor=fee_factor,
-        nonce=nonce,
-        chain_id=chain_id,
-    )
-    print(to_json(tx))
-
-
-governance_group.add_command(set_max_unbond_applied_gas)
-
-
-@command()
-@rpc_endpoint_option
-@keyfile_option()
-@from_option
-@tx_aux_options
-@argument("gas_value_str", metavar="gas", nargs=1)
-def set_max_unbond_released_gas(
-    rpc_endpoint: Optional[str],
-    keyfile: Optional[str],
-    from_str: Optional[str],
-    gas: Optional[str],
-    gas_price: Optional[str],
-    max_priority_fee_per_gas: Optional[str],
-    max_fee_per_gas: Optional[str],
-    fee_factor: Optional[float],
-    nonce: Optional[int],
-    chain_id: Optional[int],
-    gas_value_str: str,
-) -> None:
-    """
-    Set the maximum unbond released gas. Restricted to the operator account.
-    See `setMaxBondAppliedGas` on the Autonity contract.
-    """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
-
-    gas_value = parse_wei_representation(gas_value_str)
-    from_addr = from_address_from_argument(from_str, keyfile)
-    aut = autonity_from_endpoint_arg(rpc_endpoint)
-
-    tx = create_contract_tx_from_args(
-        function=aut.set_max_unbond_released_gas(gas_value),
-        from_addr=from_addr,
-        gas=gas,
-        gas_price=gas_price,
-        max_fee_per_gas=max_fee_per_gas,
-        max_priority_fee_per_gas=max_priority_fee_per_gas,
-        fee_factor=fee_factor,
-        nonce=nonce,
-        chain_id=chain_id,
-    )
-    print(to_json(tx))
-
-
-governance_group.add_command(set_max_unbond_released_gas)
-
-
-@command()
-@rpc_endpoint_option
-@keyfile_option()
-@from_option
-@tx_aux_options
-@argument("gas_value_str", metavar="gas", nargs=1)
-def set_max_rewards_distribution_gas(
-    rpc_endpoint: Optional[str],
-    keyfile: Optional[str],
-    from_str: Optional[str],
-    gas: Optional[str],
-    gas_price: Optional[str],
-    max_priority_fee_per_gas: Optional[str],
-    max_fee_per_gas: Optional[str],
-    fee_factor: Optional[float],
-    nonce: Optional[int],
-    chain_id: Optional[int],
-    gas_value_str: str,
-) -> None:
-    """
-    Set the maximum rewards distribution gas. Restricted to the operator account.
-    See `setMaxBondAppliedGas` on the Autonity contract.
-    """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
-
-    gas_value = parse_wei_representation(gas_value_str)
-    from_addr = from_address_from_argument(from_str, keyfile)
-    aut = autonity_from_endpoint_arg(rpc_endpoint)
-
-    tx = create_contract_tx_from_args(
-        function=aut.set_max_rewards_distribution_gas(gas_value),
-        from_addr=from_addr,
-        gas=gas,
-        gas_price=gas_price,
-        max_fee_per_gas=max_fee_per_gas,
-        max_priority_fee_per_gas=max_priority_fee_per_gas,
-        fee_factor=fee_factor,
-        nonce=nonce,
-        chain_id=chain_id,
-    )
-    print(to_json(tx))
-
-
-governance_group.add_command(set_max_rewards_distribution_gas)
-
-
-@command()
-@rpc_endpoint_option
-@keyfile_option()
-@from_option
-@tx_aux_options
-@argument("gas_value_str", metavar="gas", nargs=1)
-def set_staking_gas_price(
-    rpc_endpoint: Optional[str],
-    keyfile: Optional[str],
-    from_str: Optional[str],
-    gas: Optional[str],
-    gas_price: Optional[str],
-    max_priority_fee_per_gas: Optional[str],
-    max_fee_per_gas: Optional[str],
-    fee_factor: Optional[float],
-    nonce: Optional[int],
-    chain_id: Optional[int],
-    gas_value_str: str,
-) -> None:
-    """
-    Set the gas price for notification on staking operation. Restricted to the
-    operator account. See `setStakingGasPrice` on the Autonity contract.
-    """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
-
-    gas_value = parse_wei_representation(gas_value_str)
-    from_addr = from_address_from_argument(from_str, keyfile)
-    aut = autonity_from_endpoint_arg(rpc_endpoint)
-
-    tx = create_contract_tx_from_args(
-        function=aut.set_staking_gas_price(gas_value),
-        from_addr=from_addr,
-        gas=gas,
-        gas_price=gas_price,
-        max_fee_per_gas=max_fee_per_gas,
-        max_priority_fee_per_gas=max_priority_fee_per_gas,
-        fee_factor=fee_factor,
-        nonce=nonce,
-        chain_id=chain_id,
-    )
-    print(to_json(tx))
-
-
-governance_group.add_command(set_staking_gas_price)
+governance_group.add_command(create_schedule)
 
 
 @command()
@@ -301,16 +97,11 @@ def set_minimum_base_fee(
     base_fee_str: str,
 ) -> None:
     """
-    Set the minimum gas price. Restricted to the operator account.
-    See `setMinimumBaseFee` on the Autonity contract.
+    Set the minimum base fee.
+
+    Restricted to the operator account.
+    See `setMinimumBaseFee` on Autonity contract.
     """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
 
     base_fee = parse_wei_representation(base_fee_str)
     from_addr = from_address_from_argument(from_str, keyfile)
@@ -333,6 +124,52 @@ def set_minimum_base_fee(
 governance_group.add_command(set_minimum_base_fee)
 
 
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("duration", type=int, nargs=1)
+def set_max_schedule_duration(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    duration: int,
+) -> None:
+    """
+    Set the max allowed duration of any schedule or contract.
+
+    Restricted to the operator account.
+    See `setMaxScheduleDuration` on Autonity contract.
+    """
+
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_max_schedule_duration(duration),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_max_schedule_duration)
+
+
 @command()
 @rpc_endpoint_option
 @keyfile_option()
@@ -353,15 +190,10 @@ def set_committee_size(
     committee_size: int,
 ) -> None:
     """
-    Set the maximum size of the consensus committee. Restricted to the
-    Operator account.  See `setCommitteeSize` on Autonity contract.
+    Set the maximum size of the consensus committee.
+
+    Restricted to the Operator account. See `setCommitteeSize` on Autonity contract.
     """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
 
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
@@ -403,15 +235,10 @@ def set_unbonding_period(
     unbonding_period: int,
 ) -> None:
     """
-    Set the unbonding period. Restricted to the Operator account.  See
-    `setUnbondingPeriod` on Autonity contract.
+    Set the unbonding period.
+
+    Restricted to the Operator account. See `setUnbondingPeriod` on Autonity contract.
     """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
 
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
@@ -433,6 +260,190 @@ def set_unbonding_period(
 governance_group.add_command(set_unbonding_period)
 
 
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("proposer-reward-rate", type=int)
+def set_proposer_reward_rate(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    proposer_reward_rate: int,
+):
+    """
+    Set the proposer reward rate for the policy configuration.
+
+    Restricted to the Operator account.
+    See `setProposerRewardRate` on Autonity contract.
+    """
+
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_proposer_reward_rate(proposer_reward_rate),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_proposer_reward_rate)
+
+
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("oracle-reward-rate", type=int)
+def set_oracle_reward_rate(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    oracle_reward_rate: int,
+):
+    """
+    Set the unbonding period.
+
+    Restricted to the Operator account. See `setOracleRewardRate` on Autonity contract.
+    """
+
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_oracle_reward_rate(oracle_reward_rate),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_oracle_reward_rate)
+
+
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("withholding_threshold", type=int)
+def set_withholding_threshold(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    withholding_threshold: int,
+):
+    """
+    Set the withholding threshold for the policy configuration.
+
+    Restricted to the Operator account.
+    See `setWithholdingThreshold` on Autonity contract.
+    """
+
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_withholding_threshold(withholding_threshold),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_withholding_threshold)
+
+
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("pool-address-str", type=int)
+def set_withheld_rewards_pool(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    pool_address_str: str,
+):
+    """
+    Set the address of the pool to which withheld rewards will be sent.
+
+    Restricted to the Operator account.
+    See `setWithheldRewardsPool` on Autonity contract.
+    """
+
+    pool_address = Web3.to_checksum_address(pool_address_str)
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_withheld_rewards_pool(pool_address),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_withheld_rewards_pool)
+
+
 @command()
 @rpc_endpoint_option
 @keyfile_option()
@@ -453,15 +464,10 @@ def set_epoch_period(
     epoch_period: int,
 ) -> None:
     """
-    Set the epoch period. Restricted to the Operator account.  See
-    `setEpochPeriod` on Autonity contract.
+    Set the epoch period.
+
+    Restricted to the Operator account. See `setEpochPeriod` on Autonity contract.
     """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
 
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
@@ -503,19 +509,12 @@ def set_operator_account(
     operator_address_str: str,
 ) -> None:
     """
-    Set the Operator account. Restricted to the Operator account.  See
-    `setOperatorAccount` on Autonity contract.
+    Set the Operator account.
+
+    Restricted to the Operator account. See `setOperatorAccount` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    operator_address = to_checksum_address(operator_address_str)
+    operator_address = Web3.to_checksum_address(operator_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -556,19 +555,12 @@ def set_treasury_account(
     treasury_address_str: str,
 ) -> None:
     """
-    Set the global treasury account. Restricted to the Operator
-    account.  See `setTreasuryAccount` on Autonity contract.
+    Set the global treasury account.
+
+    Restricted to the Operator account. See `setTreasuryAccount` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    treasury_address = to_checksum_address(treasury_address_str)
+    treasury_address = Web3.to_checksum_address(treasury_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -609,16 +601,10 @@ def set_treasury_fee(
     treasury_fee_str: str,
 ) -> None:
     """
-    Set the treasury fee. Restricted to the Operator account.  See
-    `setTreasuryFee` on Autonity contract.
+    Set the treasury fee.
+
+    Restricted to the Operator account. See `setTreasuryFee` on Autonity contract.
     """
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_wei_representation,
-        to_json,
-    )
 
     treasury_fee = parse_wei_representation(treasury_fee_str)
     from_addr = from_address_from_argument(from_str, keyfile)
@@ -661,19 +647,13 @@ def set_accountability_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the Accountability Contract address. Restricted to the Operator account.  See
-    `setAccountabilityContract` on Autonity contract.
+    Set the Accountability Contract address.
+
+    Restricted to the Operator account.
+    See `setAccountabilityContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -714,19 +694,12 @@ def set_oracle_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the Oracle Contract address. Restricted to the Operator account.  See
-    `setOracleContract` on Autonity contract.
+    Set the Oracle Contract address.
+
+    Restricted to the Operator account. See `setOracleContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -767,19 +740,12 @@ def set_acu_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the ACU Contract address. Restricted to the Operator account.  See
-    `setAcuContract` on Autonity contract.
+    Set the ACU Contract address.
+
+    Restricted to the Operator account. See `setAcuContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -820,19 +786,13 @@ def set_supply_control_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the Supply Control Contract address. Restricted to the Operator account.  See
-    `setSupplyControlContract` on Autonity contract.
+    Set the Supply Control Contract address.
+
+    Restricted to the Operator account.
+    See `setSupplyControlContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -873,19 +833,13 @@ def set_stabilization_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the Supply Control Contract address. Restricted to the Operator account.  See
-    `setSupplyControlContract` on Autonity contract.
+    Set the Supply Control Contract address.
+
+    Restricted to the Operator account.
+    See `setSupplyControlContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -926,19 +880,13 @@ def set_inflation_controller_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the inflation controller contract address. Restricted to the Operator
-    account. See `setInflationControllerContract` on Autonity contract.
+    Set the inflation controller contract address.
+
+    Restricted to the Operator account.
+    See `setInflationControllerContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -979,19 +927,13 @@ def set_upgrade_manager_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the upgrade manager contract address. Restricted to the Operator account.
+    Set the upgrade manager contract address.
+
+    Restricted to the Operator account.
     See `setUpgradeManagerContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -1018,7 +960,7 @@ governance_group.add_command(set_upgrade_manager_contract)
 @from_option
 @tx_aux_options
 @argument("contract-address-str", metavar="CONTRACT-ADDRESS", nargs=1)
-def set_non_stakable_vesting_contract(
+def set_omission_accountability_contract(
     rpc_endpoint: Optional[str],
     keyfile: Optional[str],
     from_str: Optional[str],
@@ -1032,24 +974,18 @@ def set_non_stakable_vesting_contract(
     contract_address_str: str,
 ) -> None:
     """
-    Set the non stakable vesting contract address. Restricted to the Operator
-    account. See `setNonStakableVestingContract` on Autonity contract.
+    Set the Omission Accountability contract address.
+
+    Restricted to the Operator account.
+    See `setOmissionAccountabilityContract` on Autonity contract.
     """
-    from eth_utils import to_checksum_address
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        to_json,
-    )
-
-    contract_address = to_checksum_address(contract_address_str)
+    contract_address = Web3.to_checksum_address(contract_address_str)
     from_addr = from_address_from_argument(from_str, keyfile)
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
     tx = create_contract_tx_from_args(
-        function=aut.set_non_stakable_vesting_contract(contract_address),
+        function=aut.set_omission_accountability_contract(contract_address),
         from_addr=from_addr,
         gas=gas,
         gas_price=gas_price,
@@ -1062,7 +998,54 @@ def set_non_stakable_vesting_contract(
     print(to_json(tx))
 
 
-governance_group.add_command(set_non_stakable_vesting_contract)
+governance_group.add_command(set_omission_accountability_contract)
+
+
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("contract-address-str", metavar="CONTRACT-ADDRESS", nargs=1)
+def set_liquid_logic_contract(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    contract_address_str: str,
+) -> None:
+    """
+    Set the Liquid Logic contract address.
+
+    Restricted to the Operator account.
+    See `setAccountabilityContract` on Autonity contract.
+    """
+
+    contract_address = Web3.to_checksum_address(contract_address_str)
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_liquid_logic_contract(contract_address),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_liquid_logic_contract)
 
 
 @command()
@@ -1087,24 +1070,15 @@ def mint(
     recipient_str: Optional[str],
 ) -> None:
     """
-    Mint new stake token (NTN) and add it to the recipient balance. If
-    recipient is not specified, the caller's address is used.
-    Restricted to the Operator account.  See `mint` on Autonity
-    contract.
-    """
-    from eth_utils import to_checksum_address
+    Mint new stake token (NTN) and add it to the recipient balance.
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_newton_value_representation,
-        to_json,
-    )
+    If recipient is not specified, the caller's address is used.
+    Restricted to the Operator account. See `mint` on Autonity contract.
+    """
 
     token_units = parse_newton_value_representation(amount_str)
     from_addr = from_address_from_argument(from_str, keyfile)
-    recipient = to_checksum_address(recipient_str) if recipient_str else from_addr
+    recipient = Web3.to_checksum_address(recipient_str) if recipient_str else from_addr
 
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
@@ -1147,24 +1121,16 @@ def burn(
     account_str: Optional[str],
 ) -> None:
     """
-    Burn the specified amount of NTN stake token from an account.  If
-    account is not specified, the caller's address is used. Restricted
-    to the Operator account.  This won't burn associated Liquid
-    tokens.  See `burn` on Autonity contract.
-    """
-    from eth_utils import to_checksum_address
+    Burn the specified amount of NTN stake token from an account.
 
-    from ..utils import (
-        autonity_from_endpoint_arg,
-        create_contract_tx_from_args,
-        from_address_from_argument,
-        parse_newton_value_representation,
-        to_json,
-    )
+    If account is not specified, the caller's address is used.
+    This won't burn associated Liquid tokens.
+    Restricted to the Operator account. See `burn` on Autonity contract.
+    """
 
     token_units = parse_newton_value_representation(amount_str)
     from_addr = from_address_from_argument(from_str, keyfile)
-    account = to_checksum_address(account_str) if account_str else from_addr
+    account = Web3.to_checksum_address(account_str) if account_str else from_addr
     aut = autonity_from_endpoint_arg(rpc_endpoint)
 
     tx = create_contract_tx_from_args(
@@ -1182,3 +1148,48 @@ def burn(
 
 
 governance_group.add_command(burn)
+
+
+@command()
+@rpc_endpoint_option
+@keyfile_option()
+@from_option
+@tx_aux_options
+@argument("slasher-address-str", metavar="SLASHER-ADDRESS")
+def set_slasher(
+    rpc_endpoint: Optional[str],
+    keyfile: Optional[str],
+    from_str: Optional[str],
+    gas: Optional[str],
+    gas_price: Optional[str],
+    max_priority_fee_per_gas: Optional[str],
+    max_fee_per_gas: Optional[str],
+    fee_factor: Optional[float],
+    nonce: Optional[int],
+    chain_id: Optional[int],
+    slasher_address_str: str,
+):
+    """
+    Set the slasher account.
+
+    Restricted to the Operator account. See `setSlasher` on Autonity contract.
+    """
+    slasher_address = Web3.to_checksum_address(slasher_address_str)
+    from_addr = from_address_from_argument(from_str, keyfile)
+    aut = autonity_from_endpoint_arg(rpc_endpoint)
+
+    tx = create_contract_tx_from_args(
+        function=aut.set_slasher(slasher_address),
+        from_addr=from_addr,
+        gas=gas,
+        gas_price=gas_price,
+        max_fee_per_gas=max_fee_per_gas,
+        max_priority_fee_per_gas=max_priority_fee_per_gas,
+        fee_factor=fee_factor,
+        nonce=nonce,
+        chain_id=chain_id,
+    )
+    print(to_json(tx))
+
+
+governance_group.add_command(set_slasher)
