@@ -4,38 +4,41 @@ Utility functions that are only meant to be called by other functions in this pa
 
 import json
 import os
+import re
 import sys
+from dataclasses import asdict, is_dataclass
 from datetime import datetime, timezone
 from decimal import Decimal
 from getpass import getpass
 from typing import Any, Dict, Mapping, Optional, Sequence, Tuple, TypeVar, Union, cast
 
 from autonity import Autonity
-from autonity.abi_manager import ABIManager
-from autonity.utils.denominations import NEWTON_DECIMALS
-from autonity.utils.keyfile import get_address_from_keyfile, load_keyfile
-from autonity.utils.tx import (
-    create_contract_function_transaction,
-    create_transaction,
-    finalize_transaction,
-)
-from autonity.utils.web3 import create_web3_for_endpoint
+from autonity.contracts import autonity
+from autonity.constants import AUTONITY_CONTRACT_ADDRESS
 from click import ClickException
-from web3 import Web3
+from eth_typing import ABI, ChecksumAddress
+from hexbytes import HexBytes
+from web3 import HTTPProvider, IPCProvider, LegacyWebSocketProvider, Web3
 from web3.contract.contract import ContractFunction
+from web3.providers import BaseProvider
 from web3.types import (
-    ABI,
     BlockIdentifier,
-    ChecksumAddress,
-    HexBytes,
     Nonce,
     TxParams,
     Wei,
 )
+from web3._utils.encoding import Web3JsonEncoder
 
 from . import config
-from .constants import AutonDenoms
+from .constants import AutonDenoms, COMMISSION_RATE_PRECISION
+from .denominations import NEWTON_DECIMALS
+from .keyfile import get_address_from_keyfile, load_keyfile
 from .logging import log
+from .tx import (
+    create_contract_function_transaction,
+    create_transaction,
+    finalize_transaction,
+)
 
 # pylint: disable=too-many-arguments
 # pylint: disable=too-many-locals
@@ -45,6 +48,13 @@ from .logging import log
 V = TypeVar("V")
 
 
+class JSONEncoder(Web3JsonEncoder):
+    def default(self, obj: Any) -> Any:
+        if is_dataclass(obj):
+            return asdict(obj)  # type: ignore
+        return super().default(obj)
+
+
 def web3_from_endpoint_arg(w3: Optional[Web3], endpoint_arg: Optional[str]) -> Web3:
     """
     Construct a Web3 from a cli argument.  CLI argument is not
@@ -63,16 +73,32 @@ def web3_from_endpoint_arg(w3: Optional[Web3], endpoint_arg: Optional[str]) -> W
     """
 
     if w3 is None:
-        # TODO: For now, ignore the chain ID by default.  Later, this
-        # check should be enabled and controllable by a flag.
-        return create_web3_for_endpoint(
-            config.get_rpc_endpoint(endpoint_arg), ignore_chain_id=True
-        )
-
+        return Web3(web3_provider_for_endpoint(config.get_rpc_endpoint(endpoint_arg)))
     return w3
 
 
-def autonity_from_endpoint_arg(endpoint_arg: Optional[str]) -> Autonity:
+def web3_provider_for_endpoint(endpoint: str) -> BaseProvider:
+    """
+    Given an rpc endpoint, return an appropriate provider (https, ws,
+    or IPC). If identifier isn't a valid format of one of these three
+    types, throws an exception.
+    """
+    regex_http = re.compile(r"^(?:http)s?://")
+    if re.match(regex_http, endpoint) is not None:
+        return HTTPProvider(endpoint)
+
+    regex_ws = re.compile(r"^(?:ws)s?://")
+    if re.match(regex_ws, endpoint) is not None:
+        return LegacyWebSocketProvider(endpoint)
+
+    regex_ipc = re.compile("([^ !$`&*()+]|(\\[ !$`&*()+]))+\\.ipc")
+    if re.match(regex_ipc, endpoint) is not None:
+        return IPCProvider(endpoint)
+
+    raise ValueError(f"cannot determine provider for: {endpoint}")
+
+
+def autonity_from_endpoint_arg(endpoint_arg: Optional[str]) -> autonity.Autonity:
     """
     Construct a reference to the Autonity contract from an endpoint
     argument.  Intended for the case of Protocol queries where the CLI
@@ -147,7 +173,8 @@ def create_tx_from_args(
         w3 = web3_from_endpoint_arg(w3, rpc_endpoint)
         block_number = w3.eth.block_number
         block_data = w3.eth.get_block(block_number)
-        max_fee_per_gas = str(Wei(int(float(block_data["baseFeePerGas"]) * fee_factor)))
+        if base_fee_per_gas := block_data.get("baseFeePerGas"):
+            max_fee_per_gas = str(Wei(int(float(base_fee_per_gas) * fee_factor)))
 
     try:
         return (
@@ -156,7 +183,7 @@ def create_tx_from_args(
                 to_addr=to_addr,
                 value=parse_wei_representation(value) if value else None,
                 data=HexBytes(data) if data else None,
-                gas=parse_wei_representation(gas) if gas else None,
+                gas=int(gas) if gas else None,
                 gas_price=parse_wei_representation(gas_price) if gas_price else None,
                 max_fee_per_gas=(
                     parse_wei_representation(max_fee_per_gas)
@@ -220,18 +247,17 @@ def create_contract_tx_from_args(
         block_data = w3.eth.get_block(block_number)
         # Note, keep this in units of whole Auton.  It will be
         # converted to Wei below.
-        max_fee_per_gas = str(
-            Decimal(block_data["baseFeePerGas"])
-            * Decimal(fee_factor)
-            / Decimal(pow(10, 18))
-        )
+        if base_fee_per_gas := block_data.get("baseFeePerGas"):
+            max_fee_per_gas = str(
+                Decimal(base_fee_per_gas) * Decimal(fee_factor) / Decimal(pow(10, 18))
+            )
 
     try:
         tx = create_contract_function_transaction(
             function=function,
             from_addr=from_addr,
             value=parse_wei_representation(value) if value else None,
-            gas=parse_wei_representation(gas) if gas else None,
+            gas=int(gas) if gas else None,
             gas_price=parse_wei_representation(gas_price) if gas_price else None,
             max_fee_per_gas=(
                 parse_wei_representation(max_fee_per_gas) if max_fee_per_gas else None
@@ -250,27 +276,6 @@ def create_contract_tx_from_args(
         raise ClickException(err.args[0]) from err
 
 
-# TODO: remove
-def w3_provider() -> Web3:
-    """
-    Return a web3py provider object for the RPC identifier that
-    w3_provider_endpoint returns.
-    """
-    return Web3()  # web3_from_endpoint(w3_provider_endpoint())
-
-
-def w3_provider_is_connected(w3: Web3) -> bool:
-    """
-    Take a web3py RPC provider object and return true if connected
-    to the provider, otherwise throw exception.
-    """
-    # identifier = w3_provider_endpoint()
-    if not w3.is_connected():
-        raise OSError("Web3 is not connected")
-
-    return True
-
-
 def parse_wei_representation(wei_str: str) -> Wei:
     """
     Take a text representation of an integer with an optional
@@ -348,15 +353,6 @@ def address_keyfile_dict(keystore_dir: str) -> Dict[ChecksumAddress, str]:
     return addr_keyfile_dict
 
 
-def degeneate_address_keyfile_dict(keystore_dir: str) -> Dict[str, str]:
-    """
-    Similar to address_keyfile_dict, but addresses (keys) are
-    lower case and without the '0x' prefix.
-    """
-    addr_keyfile_dict = address_keyfile_dict(keystore_dir)
-    return {k.lower().replace("0x", ""): v for k, v in addr_keyfile_dict.items()}
-
-
 def to_checksum_address(address: str) -> ChecksumAddress:
     """
     Take a blockchain address as string, convert the string into
@@ -373,10 +369,9 @@ def to_json(data: Union[Mapping[str, V], Sequence[V]], pretty: bool = False) ->
     Note, the `Mapping[K, V]` type allows all `TypedDict` types
     (`TxParams`, `SignedTx`, etc) to be passed in.
     """
-    if pretty:
-        return json.dumps(cast(Dict[Any, Any], data), indent=2)
-
-    return Web3.to_json(cast(Dict[Any, Any], data))
+    return json.dumps(
+        cast(Dict[Any, Any], data), indent=(2 if pretty else None), cls=JSONEncoder
+    )
 
 
 def string_is_32byte_hash(hash_str: str) -> bool:
@@ -472,7 +467,7 @@ def newton_or_token_to_address(
                 "cannot use --ntn and --token <addr> arguments together"
             )
 
-        return Autonity.address()
+        return AUTONITY_CONTRACT_ADDRESS
 
     if token:
         return Web3.to_checksum_address(token)
@@ -561,28 +556,38 @@ def contract_address_and_abi_from_args(
         config.get_contract_address(contract_address_str)
     )
     contract_abi_path = config.get_contract_abi(contract_abi_path)
-    contract_abi = ABIManager.load_abi_file(contract_abi_path)
+    contract_abi = _load_abi_file(contract_abi_path)
     return contract_address, contract_abi
 
 
-def parse_commission_rate(rate_str: str, rate_precision: int) -> int:
+def _load_abi_file(file_name: str) -> ABI:
+    """
+    Load an ABI from a file.
+    """
+    with open(file_name, "r", encoding="utf8") as abi_f:
+        return json.load(abi_f)
+
+
+def parse_commission_rate(rate_str: str) -> int:
     """
     Support multiple rate formats and parse to a fixed-precision int
     argument.
     """
-
     # Handle ambiguous case
     if rate_str == "1" or rate_str.startswith("1.0"):
         raise ClickException(
-            f"ambiguous rate.  Use X%, 0.xx or a fixed-point value (out of {rate_precision}"
+            "ambiguous rate. Use X%, 0.xx or a fixed-point value "
+            f"(out of {COMMISSION_RATE_PRECISION}"
         )
 
     if rate_str.endswith("%"):
-        return int(Decimal(rate_precision) * Decimal(rate_str[:-1]) / Decimal(100))
+        return int(
+            Decimal(COMMISSION_RATE_PRECISION) * Decimal(rate_str[:-1]) / Decimal(100)
+        )
 
     rate_dec = Decimal(rate_str)
     if rate_dec < Decimal(1):
-        return int(Decimal(rate_precision) * rate_dec)
+        return int(Decimal(COMMISSION_RATE_PRECISION) * rate_dec)
 
     try:
         rate_int = int(rate_str)
